@@ -42,7 +42,7 @@ plotdist <- function(data,distr,para,breaks="default",discrete=FALSE,...){
             else 
                 h<-hist(data,freq=FALSE,xlab="data",main=paste("Histogram"),breaks=breaks,...)
             plot(s,obsp,main=paste("Cumulative distribution"),xlab="data",
-            xlim=c(h$breaks[1],h$breaks[length(h$breaks)]),ylab="CDF",pch=4,...)
+            xlim=c(h$breaks[1],h$breaks[length(h$breaks)]),ylab="CDF",...)
         }
         else {
             # plot for discrete data
@@ -54,11 +54,11 @@ plotdist <- function(data,distr,para,breaks="default",discrete=FALSE,...){
             xvalfin<-seq(min(xval),max(xval))
             ydobs<-as.vector(t)/n
             ydmax<-max(ydobs)
-            plot(xval,ydobs,type='h',lwd=5,xlim=xlim,ylim=c(0,ydmax),
+            plot(xval,ydobs,type='h',xlim=xlim,ylim=c(0,ydmax),
             main="Empirical distribution",xlab="data",ylab="Density",...)
             # plot of the cumulative probability distributions
             ycdfobs<-ecdf(data)(xvalfin)
-            plot(xvalfin,ycdfobs,type='h',lwd=5,xlim=xlim,ylim=c(0,1),
+            plot(xvalfin,ycdfobs,type='h',xlim=xlim,ylim=c(0,1),
             main="Empirical CDFs",xlab="data",ylab="CDF",...)
         }
     } #end of if (missing(distr))
@@ -105,7 +105,7 @@ plotdist <- function(data,distr,para,breaks="default",discrete=FALSE,...){
                 h <- hist(data,breaks=breaks,plot=FALSE,...)           
             xhist <- seq(min(h$breaks),max(h$breaks),length=1000)
             yhist <- do.call(ddistname,c(list(x=xhist),as.list(para)))
-            ymax <- max(max(h$density),max(yhist)) 
+            ymax <- ifelse(is.finite(max(yhist)),max(max(h$density),max(yhist)),max(h$density)) 
             # plot of histograms and theoretical density
             hist(data,freq=FALSE,xlab="data",ylim=c(0,ymax),breaks=h$breaks,
                 main=paste("Empirical and theoretical distr."),...)
@@ -121,7 +121,7 @@ plotdist <- function(data,distr,para,breaks="default",discrete=FALSE,...){
             xmin<-h$breaks[1]
             xmax<-h$breaks[length(h$breaks)]
             plot(s,obsp,main=paste("Empirical and theoretical CDFs"),xlab="data",
-            ylab="CDF",xlim=c(xmin,xmax),pch=4,...)
+            ylab="CDF",xlim=c(xmin,xmax),...)
             sfin<-seq(xmin,xmax,by=(xmax-xmin)/100)
             theopfin<-do.call(pdistname,c(list(q=sfin),as.list(para)))
             lines(sfin,theopfin,lty=1)
@@ -142,14 +142,15 @@ plotdist <- function(data,distr,para,breaks="default",discrete=FALSE,...){
             t<-table(data)
             xval<-as.numeric(names(t))
             xvalfin<-seq(min(xval),max(xval))
+            xlinesdec <- min((max(xval)-min(xval))/100,0.4)
             yd<-do.call(ddistname,c(list(x=xvalfin),as.list(para)))
             ydobs<-as.vector(t)/n
             ydmax<-max(yd,ydobs)
-            plot(xvalfin+0.1,yd,type='h',lwd=5,xlim=c(min(xval),max(xval)+0.1),
-                ylim=c(0,ydmax),lty=1,
-                main="Empirical (black) and theoretical (red) distr.",xlab="data",
-                ylab="Density",col='red',...)
-            points(xval,ydobs,type='h',lwd=5,lty=1)
+            plot(xvalfin+xlinesdec,yd,type='h',xlim=c(min(xval),max(xval)+xlinesdec),
+                ylim=c(0,ydmax),lty=3,
+                main="Empirical (full line) and theoretical (dotted line) distr.",xlab="data",
+                ylab="Density",...)
+            points(xval,ydobs,type='h',lty=1,...)
             #legend(xval[1]+0.8*(max(xval)-min(xval)),ydmax,lty=c(1,2),
             #    legend=c("empirical",paste("theoretical")),
             #    col=c('black','red'),bty='n',cex=0.8)
@@ -157,11 +158,11 @@ plotdist <- function(data,distr,para,breaks="default",discrete=FALSE,...){
             # plot of the cumulative probability distributions
             ycdfobs<-ecdf(data)(xvalfin)
             ycdf<-do.call(pdistname,c(list(q=xvalfin),as.list(para)))
-            plot(xvalfin+0.1,ycdf,type='h',lwd=5,xlim=c(min(xval),max(xval)+0.1),
-                ylim=c(0,1),lty=1,
-                main="Empirical (black) and theoretical (red) CDFs",xlab="data",
-                ylab="CDF",col='red',...)
-            points(xvalfin,ycdfobs,type='h',lwd=5,lty=1)
+            plot(xvalfin+xlinesdec,ycdf,type='h',xlim=c(min(xval),max(xval)+xlinesdec),
+                ylim=c(0,1),lty=3,
+                main="Empirical (full line) and theoretical (dotted line) CDFs",xlab="data",
+                ylab="CDF",...)
+            points(xvalfin,ycdfobs,type='h',lty=1,...)
             #legend(xval[1],1,lty=c(1,2),legend=c("empirical",paste("theoretical")),
             #col=c('black','red'),bty='n',cex=0.8)
         }
